@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _ACPID_LOG_MODE_H_
-#define _ACPID_LOG_MODE_H_
+#ifndef ACPID_LOG_MODE_H
+#define ACPID_LOG_MODE_H
 
 /**
  * Acpid Log Mode Identifier
@@ -47,9 +47,9 @@ public:
 
     ~AcpidLogMode();
 
-    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;
+    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
+    QList<LogFile> createLogFiles() override;
 };
 
-#endif // _ACPID_LOG_MODE_H_
+#endif // _ACPID_LOG_MODE_H
