@@ -26,8 +26,8 @@
 #include <QPushButton>
 #include <QDesktopServices>
 
-#include <kactioncollection.h>
-#include <kmessagebox.h>
+#include <KActionCollection>
+#include <KMessageBox>
 #include <QIcon>
 #include <QMenu>
 #include <QFileInfo>
